function I = fresnelIntegralQuadrature(alpha, eps)
    %Returnerer en approksimativ verdi av integralet int_0^{\infty}
    %x^{-alpha} sin(x) dx ved hjelp av kvadratur.
    %Integralet regnes ut til presisjon epsilon ved  kalle en kvadratur i
    %C som er laget spesielt for formlet (se dokumentasjon under C-filer
    %for link til kilden). Hvis alpha er for nrme 2, s m deler av
    %integralet tilnrmes analytisk med Taylorrekker.
    alphaLimit = 1.85;
    if(alpha <= 0 || alpha >= 2)
        error('0<alpha<2 is required!');
    end
    if(alpha<alphaLimit)
        %betyr at det gr bra  regne ut integralet numerisk fra 0 til
        %infty
        [I, errorEstimate] = oscillatorQuadrature(alpha, eps, 0);
    else
        %alpha>alphaLimit.
        %Regner ut integralet fra 0 til a semianalytisk
        %og fra a til infty numerisk.
        %a bestemmes ved at vi krever at integranden ikke er strre enn 10
        %i a
        integrandUpperLimit = 10;
        searchStartingPoint = 1e-4;
        fsolveFunction = @(x) abs(x.^(-alpha).*sin(x)) - integrandUpperLimit;
        a = fsolve(fsolveFunction,searchStartingPoint, optimset('Display','off'));
        
        I1 = getBoundaryLayerIntegral(alpha, a, eps);
        [I2, errorEstimate] = oscillatorQuadrature(alpha, eps, a);
        I = I1 + I2;
    end
end