function spatial_odefunction = getSpatial_odefunction(alpha, N, eps, SVV, quadratic_f, quadratic_A)
    %Returnerer en funksjonspeker. eps angir presisjon i kvadratur av
    %ikkelokale integraler
    %Funksjonspekerens retur er den tidsderiverte av koeffisientvektoren (ut fra den
    %variasjonelle likningen)
    %Skiller denne ut i en egen funksjon slik at hvis den endres ett sted,
    %gjelder det for alle typer ODE-lsere som brukes i simuleringene.
    %Antar at N==length(a), der a defineres i
    %spatial_odefunction-funksjonspekeren nedenfor
    
    %Trenger bare beregne disse strrelsene en gang
    viscosityModule = getViscosityModule(N, SVV);
    sourceTermIntegrals = getSourceTermIntegrals(N);
    if(alpha>0 && alpha<2)
        nonlocalIntegrals = getNonlocalIntegrals(N, alpha, eps); 
        %Selve funksjonspekeren:
        if(quadratic_f==0)
            if(quadratic_A==0)
                spatial_odefunction = @(t,a) a.*nonlocalIntegrals - viscosityModule*(-N:N)'.^2.*getViscosityCoefficients(N,t).*a - 0.5*1i*(-N:N)'.*a + sourceTermIntegrals;
            elseif(quadratic_A==1)
                spatial_odefunction = @(t,a) getQuadraticCoefficients(a).*nonlocalIntegrals - viscosityModule*(-N:N)'.^2.*getViscosityCoefficients(N,t).*a - 0.5*1i*(-N:N)'.*a + sourceTermIntegrals;
            else
                error('Illegal value for quadratic_A!');
            end
        elseif(quadratic_f==1)
            if(quadratic_A==0)
                spatial_odefunction = @(t,a) a.*nonlocalIntegrals - viscosityModule*(-N:N)'.^2.*getViscosityCoefficients(N,t).*a - 0.5*1i*(-N:N)'.*getQuadraticCoefficients(a) + sourceTermIntegrals;
            elseif(quadratic_A==1)
                spatial_odefunction = @(t,a) getQuadraticCoefficients(a).*nonlocalIntegrals - viscosityModule*(-N:N)'.^2.*getViscosityCoefficients(N,t).*a - 0.5*1i*(-N:N)'.*getQuadraticCoefficients(a) + sourceTermIntegrals;
            else
                error('Illegal value for quadratic_A!');
            end
        else
            error('Illegal value for quadratic_f!');
        end
    elseif(alpha==2) %Svarer til "vanlig" Laplace med en faktor (1/(4pi^2)) foran.
        %Selve funksjonspekeren: 
        if(quadratic_f==0)
            if(quadratic_A==0)
                spatial_odefunction = @(t,a) a.*(-(-N:N)'.^2*(1/(2*pi))^2) - viscosityModule*(-N:N)'.^2.*getViscosityCoefficients(N,t).*a - 0.5*1i*(-N:N)'.*a + sourceTermIntegrals;
            elseif(quadratic_A==1)
                spatial_odefunction = @(t,a) getQuadraticCoefficients(a).*(-(-N:N)'.^2*(1/(2*pi))^2) - viscosityModule*(-N:N)'.^2.*getViscosityCoefficients(N,t).*a - 0.5*1i*(-N:N)'.*a + sourceTermIntegrals;
            else
                error('Illegal value for quadratic_A!');
            end
        elseif(quadratic_f==1)
            if(quadratic_A==0)
                spatial_odefunction = @(t,a) a.*(-(-N:N)'.^2*(1/(2*pi))^2) - viscosityModule*(-N:N)'.^2.*getViscosityCoefficients(N,t).*a - 0.5*1i*(-N:N)'.*getQuadraticCoefficients(a) + sourceTermIntegrals;
            elseif(quadratic_A==1)
                spatial_odefunction = @(t,a) getQuadraticCoefficients(a).*(-(-N:N)'.^2*(1/(2*pi))^2) - viscosityModule*(-N:N)'.^2.*getViscosityCoefficients(N,t).*a - 0.5*1i*(-N:N)'.*getQuadraticCoefficients(a) + sourceTermIntegrals;
            else
                error('Illegal value for quadratic_A!');
            end
        else
           error('Illegal value for quadratic_f!');
        end
    else
        error('Illegal value for alpha!');
    end
end