function spatial_odefunction = getSpatial_odefunction(alpha, N, eps, dealiasing, SVV)
    %Returnerer en funksjonspeker. eps angir presisjon i kvadratur av
    %ikkelokale integraler
    %Funksjonspekerens retur er den tidsderiverte av koeffisientvektoren (ut fra den
    %variasjonelle likningen)
    %Skiller denne ut i en egen funksjon slik at hvis den endres ett sted,
    %gjelder det for alle typer ODE-lsere som brukes i simuleringene.
    %Antar at N==length(a), der a defineres i
    %spatial_odefunction-funksjonspekeren nedenfor
    
    %Trenger bare beregne disse strrelsene en gang
    viscosityModule = getViscosityModule(N, SVV);
    sourceTermIntegrals = getSourceTermIntegrals(N);
    viscosityCoefficients = getViscosityCoefficients(N);
    
    if(alpha>0 && alpha<2)
        nonlocalIntegrals = getNonlocalIntegrals(N, alpha, eps); 
        %Selve funksjonspekeren:
        spatial_odefunction = @(t,a) getNonlocalOperatorCoefficients(a, dealiasing).*nonlocalIntegrals - viscosityModule*(-N/2:N/2-1)'.^2.*viscosityCoefficients.*a - 1i*(-N/2:N/2-1)'.*getConvectionOperatorCoefficients(a, dealiasing) + sourceTermIntegrals;
    elseif(alpha==2) %Svarer til "vanlig" Laplace med en koeffisient (1/(4pi^2)) foran.
        %Selve funksjonspekeren:
        spatial_odefunction = @(t,a) getNonlocalOperatorCoefficients(a, dealiasing).*(-(-N/2:N/2-1)'.^2*(1/(2*pi))^2) - viscosityModule*(-N/2:N/2-1)'.^2.*viscosityCoefficients.*a - 1i*(-N/2:N/2-1)'.*getConvectionOperatorCoefficients(a, dealiasing) + sourceTermIntegrals;
    else
        error('Illegal value for alpha!');
    end
end