function spatial_odefunction = getSpatial_odefunction(alpha, N, eps, SVV)
    %Returnerer en funksjonspeker. eps angir presisjon i kvadratur av
    %ikkelokale integraler
    %Funksjonspekerens retur er den tidsderiverte av koeffisientvektoren (ut fra den
    %variasjonelle likningen) i global datarepresentasjon, dvs. som en
    %vektor.
    
    %Skiller denne ut i en egen funksjon slik at hvis den endres ett sted,
    %gjelder det for alle typer ODE-lsere som brukes i simuleringene.
    %Antar at N==size(a,1), der a defineres i
    %spatial_odefunction-funksjonspekeren
    
    %Trenger bare beregne disse strrelsene en gang
    %M g til global representasjon (vektor) med reshape for at MATLABs
    %ode-lsere skal fungere
      
    viscosityCoefficients = reshape(getViscosityCoefficients(N), N^2, 1);
    viscosityModule = getViscosityModule(N, SVV);
    sourceTermIntegrals = reshape(getSourceTermIntegrals(N), N^2, 1);
    [xi_1, xi_2] = meshgrid(-N/2:N/2-1);
    xi_1 = reshape(xi_1, N^2, 1);
    xi_2 = reshape(xi_2, N^2, 1);
    
    
    if(alpha>0 && alpha<2)
        nonlocalIntegrals = reshape(getNonlocalIntegrals(N, alpha, eps), N^2, 1);  
        %Selve funksjonspekeren:
        %Funksjonspekeren. a antas  vre en kolonnevektor med lengde N^2, t er
        %tiden (skalar).
        spatial_odefunction = @(t,a) reshape(getNonlocalOperatorCoefficients(reshape(a,N,N)), N^2, 1).*nonlocalIntegrals - viscosityModule*(xi_1.^2+xi_2.^2).*viscosityCoefficients.*a - 1i*xi_1.*reshape(getConvection_x1OperatorCoefficients(reshape(a,N,N)), N^2, 1) - 1i*xi_2.*reshape(getConvection_x2OperatorCoefficients(reshape(a,N,N)), N^2, 1) + sourceTermIntegrals;
    elseif(alpha==2) %Svarer til "vanlig" Laplace med en faktor (1/(4pi^2)) foran.
        %Selve funksjonspekeren: 
        spatial_odefunction = @(t,a) reshape(getNonlocalOperatorCoefficients(reshape(a,N,N)), N^2, 1).*(xi_1.^2+xi_2.^2)*((-1)/(2*pi)^2) - viscosityModule*(xi_1.^2+xi_2.^2).*viscosityCoefficients.*a - 1i*xi_1.*reshape(getConvection_x1OperatorCoefficients(reshape(a,N,N)), N^2, 1) - 1i*xi_2.*reshape(getConvection_x2OperatorCoefficients(reshape(a,N,N)), N^2, 1) + sourceTermIntegrals;
    end
end