function Q = getViscosityCoefficients(N)
%Returnerer Fourierkoeffisientene til SVV-leddene (de hye frekvensene) ved
%tiden t
%I 2D blir Q en matrise. Her implementeres det slik at det viskositetsfri
%spekteret blir en sirkel innerst i matrisen (2-norm), men det kan ogs antakelig
%gjres p andre mter, f.eks. ved  bruke en max-norm som topologi for 
%mle grensen p spekteret. I det tilfellet blir det viskositetsfri
%spekteret en firkant innerst i matrisen

    m = getViscositySpectrumLimit(N);
    Q=zeros(N,N);
    
    for i=1:N
        xi1 = -N/2+i-1;
        for j=1:N
            xi2 = -N/2+j-1;
            xi=[xi1, xi2];
            abs_xi = norm(xi,2);
            if(abs_xi>=m) %Betyr at vi er i viskositetsdelen av spekteret
                Q(i,j) = min((norm(xi,2)-m)/m,1);
            end
        end
    end
    
    
    
    
    
%    %Max-norm-implementasjon
%     residual=N/2-m;
%     %Strste negative delen av spekteret i xi1-retning
%     for i=1:residual
%        xi1=i-N/2-1;
%        Q(i,:)=min((abs(xi1)-m)/m,1); 
%     end
%     %Strste positive delen av spekteret i xi1-retning
%     for i=m+N/2:N
%        xi1=i-N/2;
%        Q(i,:)=min((abs(xi1)-m)/m,1);
%     end
%     %Strste negative delen av spekteret i xi2-retning
%     for j=1:residual
%        xi2=j-N/2-1;
%        Q(:,j)=min((abs(xi2)-m)/m,1); 
%     end
%     %Strste positive delen av spekteret i xi2-retning
%     for j=m+N/2+1:N
%        xi2=j-N/2;
%        Q(:,j)=min((abs(xi2)-m)/m,1);
%     end
    
    
    
end