//Regner ut integralet int_0^inf x^(-alpha)*sin(omega*x) dx til presisjon eps

#include <math.h>
#include "mex.h"

double f(double x, double alpha); //Definisjon av funksjonen f nedenfor

/* Kvadraturfunksjonen */
void intdeo(double a, double alpha, double omega, double eps, double *i, double *err)
{
    /* ---- adjustable parameter ---- */
    int mmax = 256, lmax = 5;
    double efs = 0.1, enoff = 0.40, pqoff = 2.9, ppoff = -0.72;
    /* ------------------------------ */
    int n, m, l, k;
    double pi4, epsln, epsh, frq4, per2, pp, pq, ehp, ehm, ir, h, iback, 
        irback, t, ep, em, tk, xw, wg, xa, fp, fm, errh, tn, errd;
    
    pi4 = atan(1.0);
    epsln = 1 - log(efs * eps);
    epsh = sqrt(efs * eps);
    n = (int) (enoff * epsln);
    frq4 = fabs(omega) / (2 * pi4);
    per2 = 4 * pi4 / fabs(omega);
    pq = pqoff / epsln;
    pp = ppoff - log(pq * pq * frq4);
    ehp = exp(2 * pq);
    ehm = 1 / ehp;
    xw = exp(pp - 2 * pi4);
    *i = f(a + sqrt(xw * (per2 * 0.5)), alpha);
    ir = *i * xw;
    *i *= per2 * 0.5;
    *err = fabs(*i);
    h = 2;
    m = 1;
    do {
        iback = *i;
        irback = ir;
        t = h * 0.5;
        do {
            em = exp(2 * pq * t);
            ep = pi4 * em;
            em = pi4 / em;
            tk = t;
            do {
                xw = exp(pp - ep - em);
                wg = sqrt(frq4 * xw + tk * tk);
                xa = xw / (tk + wg);
                wg = (pq * xw * (ep - em) + xa) / wg;
                fm = f(a + xa, alpha);
                fp = f(a + xa + per2 * tk, alpha);
                ir += (fp + fm) * xw;
                fm *= wg;
                fp *= per2 - wg;
                *i += fp + fm;
                if (m == 1) *err += fabs(fp) + fabs(fm);
                ep *= ehp;
                em *= ehm;
                tk += 1;
            } while (ep < epsln);
            if (m == 1) {
                errh = *err * epsh;
                *err *= eps;
            }
            tn = tk;
            while (fabs(fm) > *err) {
                xw = exp(pp - ep - em);
                xa = xw / tk * 0.5;
                wg = xa * (1 / tk + 2 * pq * (ep - em));
                fm = f(a + xa, alpha);
                ir += fm * xw;
                fm *= wg;
                *i += fm;
                ep *= ehp;
                em *= ehm;
                tk += 1;
            }
            fm = f(a + per2 * tn, alpha);
            em = per2 * fm;
            *i += em;
            if (fabs(fp) > *err || fabs(em) > *err) {
                l = 0;
                for (;;) {
                    l++;
                    tn += n;
                    em = fm;
                    fm = f(a + per2 * tn, alpha);
                    xa = fm;
                    ep = fm;
                    em += fm;
                    xw = 1;
                    wg = 1;
                    for (k = 1; k <= n - 1; k++) {
                        xw = xw * (n + 1 - k) / k;
                        wg += xw;
                        fp = f(a + per2 * (tn - k), alpha);
                        xa += fp;
                        ep += fp * wg;
                        em += fp * xw;
                    }
                    wg = per2 * n / (wg * n + xw);
                    em = wg * fabs(em);
                    if (em <= *err || l >= lmax) break;
                    *i += per2 * xa;
                }
                *i += wg * ep;
                if (em > *err) *err = em;
            }
            t += h;
        } while (t < 1);
        if (m == 1) {
            errd = 1 + 2 * errh;
        } else {
            errd = h * (fabs(*i - 2 * iback) + pq * fabs(ir - 2 * irback));
        }
        h *= 0.5;
        m *= 2;
    } while (errd > errh && m < mmax);
    *i *= h;
    if (errd > errh) {
        *err = -errd;
    } else {
        *err *= m * 0.5;
    }
}

//Integranden
double f(double x, double alpha)
{
    return pow(x,-alpha)*sin(x);
}


/* The gateway function */
//nrhs svarer til antall inputvariable
//nlhs svarer til antall outputvariable
//prhs svarer til inputvariable 
//plhs svarer til inputvariable som skal sendes til C

void mexFunction( int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
    double alpha, epsilon;               /* input parameters */
    double *integral;
    double *errorEstimate;     /* output parameters */
    
    double a, omega; //other parameters

    /* check for proper number of arguments */
    if(nrhs!=3) {
        mexErrMsgIdAndTxt("MyToolbox:arrayProduct:nrhs","3 inputs required.");
    }
    if(nlhs!=2) {
        mexErrMsgIdAndTxt("MyToolbox:arrayProduct:nlhs","2 outputs required.");
    }
    /* make sure the first input argument is real scalar double */
    if( !mxIsDouble(prhs[0]) || 
         mxIsComplex(prhs[0]) ||
         mxGetNumberOfElements(prhs[0])!=1 ) {
        mexErrMsgIdAndTxt("MyToolbox:arrayProduct:notScalar","Input multiplier must be a scalar.");
    }
    
    /* make sure the second input argument is real scalar double */
    if( !mxIsDouble(prhs[1]) || 
         mxIsComplex(prhs[1]) ||
         mxGetNumberOfElements(prhs[1])!=1 ) {
        mexErrMsgIdAndTxt("MyToolbox:arrayProduct:notScalar","Input multiplier must be a scalar.");
    }
    
    /* make sure the third input argument is real scalar double */
    if( !mxIsDouble(prhs[2]) || 
         mxIsComplex(prhs[2]) ||
         mxGetNumberOfElements(prhs[2])!=1 ) {
        mexErrMsgIdAndTxt("MyToolbox:arrayProduct:notScalar","Input multiplier must be a scalar.");
    }
    
    /* get the value of the scalar input  */
    alpha = mxGetScalar(prhs[0]); //Fraksjonalitetsparameteren
    epsilon = mxGetScalar(prhs[1]); //Feilgrensen
    a=mxGetScalar(prhs[2]); //Nedre integrasjonsgrense
    omega=1; //Oscillatorfrekvens p sinusen (her 1)

    /* create the output matrices: scalar, 1x1 */
    plhs[0] = mxCreateDoubleMatrix(1,1,mxREAL);
    plhs[1] = mxCreateDoubleMatrix(1,1,mxREAL);

    /* get a pointer to the real data in the output matrix */
    integral = mxGetPr(plhs[0]);
    errorEstimate = mxGetPr(plhs[1]);

    /* call the computational routine */
    intdeo(a, alpha, omega, epsilon, integral, errorEstimate);
}

